ciliuminstaller

package
v6.4.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 11, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Overview

Package ciliuminstaller provides an installer for installing Cilium CNI on a Kubernetes cluster.

This package contains the Cilium installer implementation and client interfaces for managing Cilium installations on Kubernetes clusters.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GatewayAPICRDInstallerFunc

type GatewayAPICRDInstallerFunc func(ctx context.Context) error

GatewayAPICRDInstallerFunc is a function that installs Gateway API CRDs.

type Installer

type Installer struct {
	*cni.InstallerBase
	// contains filtered or unexported fields
}

Installer implements the installer.Installer interface for Cilium.

func NewInstaller

func NewInstaller(
	client helm.Interface,
	kubeconfig, context string,
	timeout time.Duration,
) *Installer

NewInstaller creates a new Cilium installer instance.

func NewInstallerWithDistribution

func NewInstallerWithDistribution(
	client helm.Interface,
	kubeconfig, context string,
	timeout time.Duration,
	distribution v1alpha1.Distribution,
	provider v1alpha1.Provider,
	loadBalancer v1alpha1.LoadBalancer,
) *Installer

NewInstallerWithDistribution creates a new Cilium installer instance with distribution and provider-specific configuration.

func (*Installer) Images

func (c *Installer) Images(ctx context.Context) ([]string, error)

Images returns the container images used by Cilium.

func (*Installer) Install

func (c *Installer) Install(ctx context.Context) error

Install installs or upgrades Cilium via its Helm chart.

func (*Installer) Uninstall

func (c *Installer) Uninstall(ctx context.Context) error

Uninstall removes the Helm release for Cilium.

Jump to