Documentation
¶
Overview ¶
Package ciliuminstaller provides an installer for installing Cilium CNI on a Kubernetes cluster.
This package contains the Cilium installer implementation and client interfaces for managing Cilium installations on Kubernetes clusters.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GatewayAPICRDInstallerFunc ¶
GatewayAPICRDInstallerFunc is a function that installs Gateway API CRDs.
type Installer ¶
type Installer struct {
*cni.InstallerBase
// contains filtered or unexported fields
}
Installer implements the installer.Installer interface for Cilium.
func NewInstaller ¶
func NewInstaller( client helm.Interface, kubeconfig, context string, timeout time.Duration, ) *Installer
NewInstaller creates a new Cilium installer instance.
func NewInstallerWithDistribution ¶
func NewInstallerWithDistribution( client helm.Interface, kubeconfig, context string, timeout time.Duration, distribution v1alpha1.Distribution, provider v1alpha1.Provider, loadBalancer v1alpha1.LoadBalancer, ) *Installer
NewInstallerWithDistribution creates a new Cilium installer instance with distribution and provider-specific configuration.
Click to show internal directories.
Click to hide internal directories.